ICloudStoragePlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • ICloudStoragePlatform
Implementers

Constructors

ICloudStoragePlatform()
Constructs a IcloudStoragePlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete({required String containerId, required String relativePath}) → Future<void>
Delete a file from iCloud container directory, whether it is been downloaded or not
download({required String containerId, required String relativePath, required String destinationFilePath, StreamHandler<double>? onProgress}) → Future<void>
Download a file from iCloud.
gather({required String containerId, StreamHandler<List<ICloudFile>>? onUpdate}) → Future<List<ICloudFile>>
Gather all the files' meta data from iCloud container.
move({required String containerId, required String fromRelativePath, required String toRelativePath}) → Future<void>
Move a file from one location to another in the iCloud container
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
upload({required String containerId, required String filePath, required String destinationRelativePath, StreamHandler<double>? onProgress}) → Future<void>
Upload a local file to iCloud.

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ ICloudStoragePlatform
The default instance of ICloudStoragePlatform to use.
getter/setter pair